### Description

This package can be used to create Vector2 and Vector3 objects. You can call on the individual points with `_.x`, `_.y`, and `_.z`. To get a tuple of all the points, use `_.tuple()`.

### Updates

**11/18/2020 - 1.0.0**<br>
Fixed Vector3.tuple() showing as (x, y, x) instead of (x, y, z)<br>
**11/17/2020 - 0.0.1**<br>
Package published<br>

### Other Information

See my other projects at https://fosterreichert.com